# ROXIE_3ML

**Magnet Model Management Layer – 3ML** is a versatile application providing a graphical user interface (GUI) for users to interact with Magnets database, view reports of models and systems, upload files, and query ROXIE models directly from the database.

## Installation

Before installing the project, ensure you have the `xcb` and `X11` libraries installed, required for the PyQt6 GUI in Unix-like OS.

Once the necessary libraries are installed, you can install the package via pip.

In order to run the application just type `roxie_3ml` in the terminal and the GUI will launch. Remember that need your personal token in order to gain access to the remote [Magnets Database](https://mmbse.app.cern.ch/).


## License

This project is licensed under the GPL-3.0-or-later license. It uses PyQt6, which is also GPL-licensed.

This project uses [Feather icons](https://feathericons.com/), which are licensed under the MIT License. See `LICENSES/LicenseRef-feather-MIT.txt` for details.
